pub struct NameParams {
pub name: String,
}Expand description
Parameters for get_display_by_name
Fields
name: StringTrait Implementations
Sourceimpl Debug for NameParams
impl Debug for NameParams
Sourceimpl<'de> Deserialize<'de> for NameParams
impl<'de> Deserialize<'de> for NameParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NameParams
impl JsonSchema for NameParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NameParams
impl RefUnwindSafe for NameParams
impl Send for NameParams
impl Sync for NameParams
impl Unpin for NameParams
impl UnsafeUnpin for NameParams
impl UnwindSafe for NameParams