pub struct PointParams {
pub x: i32,
pub y: i32,
}Expand description
Parameters for get_display_at_point
Fields
x: i32y: i32Trait Implementations
Sourceimpl Debug for PointParams
impl Debug for PointParams
Sourceimpl<'de> Deserialize<'de> for PointParams
impl<'de> Deserialize<'de> for PointParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PointParams
impl JsonSchema for PointParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PointParams
impl RefUnwindSafe for PointParams
impl Send for PointParams
impl Sync for PointParams
impl Unpin for PointParams
impl UnsafeUnpin for PointParams
impl UnwindSafe for PointParams